@@ -53,7 +53,7 @@ Circuit::Circuit( qreal x, qreal y, qreal width, qreal height, CircuitView*  par
     m_conStarted = false;
     m_createSubc = false;
     m_acceptKeys = true;
-    m_batchProcess = 0;
+    m_cicuitChange = 0;
 
     m_board = NULL;
     m_newConnector = NULL;
@@ -112,8 +112,7 @@ QString Circuit::replaceId( QString pinName )
         QString word = words.at( i );
         bool ok;
         word.toInt( &ok );  // If it converts to int, then this is old seqNumber
-        if( ok )
-        {
+        if( ok ){
             words.replace( i, m_idMap.value( word ) );
             break;
         }
@@ -130,7 +129,7 @@ Pin* Circuit::findPin( int x, int y, QString id )
     for( QGraphicsItem* it : list )
     {
         Pin* pin =  qgraphicsitem_cast<Pin*>( it );
-        if( pin && (pin->pinId().left(1) == id.left(1))) return pin; // Check if names start by same letter
+        if( pin && pin->pinId().left(1) == id.left(1) && !pin->connector() ) return pin; // Check if names start by same letter
     }
     for( QGraphicsItem* it : list ) // Not found by first letter, take first Pin
     {
@@ -287,7 +286,7 @@ void Circuit::loadStrDoc( QString &doc )
                     if     ( name == "startpinid") startpinid = val.toString();
                     else if( name == "endpinid"  ) endpinid   = val.toString();
                     else if( name == "pointList" ) pointList  = val.toString().split(",");
-                    else if( name == "uid"       ) uid        = val.toString();
+                    //else if( name == "uid"       ) uid        = val.toString();
                 }
                 if( m_pasting )
                 {
@@ -316,7 +315,7 @@ void Circuit::loadStrDoc( QString &doc )
                     endpin = findPin( itemX, itemY, endpinid );
                 }
                 if( startpin && startpin->connector() ) startpin = NULL;
-                if( endpin   && endpin->connector() )   endpin   = NULL;
+                if( endpin   && endpin->connector()   ) endpin   = NULL;
 
                 if( startpin && endpin )    // Create Connector
                 {
@@ -332,7 +331,7 @@ void Circuit::loadStrDoc( QString &doc )
                     int number = newUid.split("-").last().toInt();
                     if( number > m_conNumber ) m_conNumber = number; // Adjust Connector counter: m_conNumber
                 }
-                else if( !m_pasting && !m_undo && !m_redo )// Start or End pin not found
+                else if( !m_pasting /*&& !m_undo && !m_redo*/ )// Start or End pin not found
                 {
                     if( !startpin ) qDebug() << "\n   ERROR!!  Circuit::loadStrDoc:  null startpin in Connector" << uid << startpinid;
                     if( !endpin   ) qDebug() << "\n   ERROR!!  Circuit::loadStrDoc:  null endpin in Connector"   << uid << endpinid;
@@ -456,31 +455,12 @@ void Circuit::loadStrDoc( QString &doc )
 
     m_compList.unite( compList );
     m_nodeList.unite( nodeList );
-    m_conList.unite( conList );
-
-    if( m_pasting && !compList.isEmpty() )  {
-        beginBatchProcess();
-
-        // clear all state generated by copy component properties
-        addCompState( NULL, "New State", stateNew);
-
-        // save states
-        for( Component *comp : compList ) addCompState( comp, COMP_STATE_CREATED, stateAdd);
-        for( Node *node : nodeList ) addCompState( node, COMP_STATE_CREATED, stateAdd);
-        for( Connector *con : conList ) addCompState( con, COMP_STATE_CREATED, stateAdd);
-
-    } else {
-        if( !m_undo && !m_redo )  for( Node* joint : nodeList ) joint->checkRemove(); // Only removed if some missing connector
-    }
+    m_connList.unite( conList );
 
     // Take care about unconnected Joints
+    if( !m_undo && !m_redo )  for( Node* joint : nodeList ) joint->checkRemove(); // Only removed if some missing connector
     for( ShieldSubc* shield : shieldList ) shield->connectBoard();
 
-    if( m_pasting && !compList.isEmpty() )  {
-        saveState();
-        endBatchProcess();
-    }
-
     setAnimate( m_animate ); // Force Pin update
 
     if( m_pasting ) m_idMap.clear();
@@ -506,32 +486,13 @@ QString Circuit::circuitToString()
     QString circuit = circuitHeader();
     for( Component* comp : m_compList ) circuit += comp->toString();
     for( Node* node      : m_nodeList ) circuit += node->toString();
-    for( Connector* conn : m_conList )  circuit += conn->toString();
+    for( Connector* conn : m_connList )  circuit += conn->toString();
     circuit += "\n</circuit>";
 
     if( m_board && m_board->m_boardMode ) m_board->setBoardMode( true );
     return circuit;
 }
 
-void Circuit::clearRemovedComps()
-{
-    for( Connector *con : m_removedConnectors ) delete con;
-    for( Component *comp : m_removedComps ) delete comp;
-    m_removedComps.clear();
-    m_removedConnectors.clear();
-}
-
-void Circuit::addCompRemovedState(const QString &id, const QString &strVal)
-{
-    qDebug() << "Circuit::addCompRemovedState" << id << COMP_STATE_REMOVED;
-    compState cState;
-    cState.component = id;
-    cState.property = COMP_STATE_REMOVED;
-    cState.valStr = strVal;
-    if ( m_undo ) m_circState.compStates.prepend( cState );
-    else m_circState.compStates.append( cState );
-}
-
 bool Circuit::saveString( QString &fileName, QString doc )
 {
     QFile file( fileName );
@@ -576,6 +537,7 @@ void Circuit::importCirc(  QPointF eventpoint  )
 {
     if( m_conStarted ) return;
     m_pasting = true;
+    if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
 
     m_deltaMove = QPointF( 160, 160 );//toGrid(eventpoint);
 
@@ -585,12 +547,16 @@ void Circuit::importCirc(  QPointF eventpoint  )
 
     if( !fileName.isEmpty()
      && (fileName.endsWith(".simu") || fileName.endsWith(".sim1")) )
+    {
+        beginCicuitChange();
         loadCircuit( fileName );
-
+        /// clearCircuitState(); // clear all state generated by copy component properties
+        endCicuitChange();
+    }
     m_pasting = false;
 }
 
-Component* Circuit::createItem( QString type, QString id )
+Component* Circuit::createItem( QString type, QString id, bool map )
 {
     Component* comp = NULL;
     for( LibraryItem* item : ItemLibrary::self()->items() )
@@ -600,7 +566,7 @@ Component* Circuit::createItem( QString type, QString id )
 
         comp = item->createItemFnPtr()( type, id );
     }
-    m_compMap[id] = comp;
+    if( map) m_compMap[id] = comp;
     return comp;
 }
 
@@ -608,67 +574,43 @@ void Circuit::removeItems()                     // Remove Selected items
 {
     if( m_conStarted ) return;
     m_busy = true;
+    if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
 
-    beginBatchProcess();
-    QSet<Connector*> oldConnectors = m_conList;
-    QSet<Component*> oldComponents = m_compList;
-    QSet<Node*> oldNodes = m_nodeList;
+    beginCicuitChange(); // Save current state
 
-    //save all comps
-    QMap<CompBase *,QString> compStrMap;
-    for( Connector* con  : oldConnectors ) compStrMap.insert( con, con->toString() );
-    for( Node* node : oldNodes ) compStrMap.insert( node, node->toString() );
-    for( Component* comp : oldComponents ) compStrMap.insert( comp, comp->toString() );
+    QList<Connector*> conns;
+    QList<Component*> comps;
 
-    QList<Connector *> conns;
-    QList<Component *> comps;
-
-    //remove all connectors
-    for( QGraphicsItem* item : selectedItems())
+    // remove all connectors
+    for( QGraphicsItem* item : selectedItems() )
     {
         if( item->type() == QGraphicsItem::UserType+2 ) // ConnectorLine
         {
-            ConnectorLine* line = qgraphicsitem_cast<ConnectorLine* >( item );
+            ConnectorLine* line = qgraphicsitem_cast<ConnectorLine*>( item );
             Connector* con = line->connector();
-            conns.append( con );
-        } else if( item->type() == QGraphicsItem::UserType+1 ) // Component
+            if( !conns.contains( con ) ) conns.append( con );
+        }
+        else if( item->type() == QGraphicsItem::UserType+1 ) // Component
         {
-            Component* comp = qgraphicsitem_cast<Component* >( item );
+            Component* comp = qgraphicsitem_cast<Component*>( item );
             comps.append( comp );
         }
     }
-    for( Connector* con : conns ) {
-        if ( m_conList.contains( con ) ) removeConnector( con );
-    }
-    for( Component* comp: comps ) {
-        if ( m_compList.contains( comp ) ) {
-            if ( comp->itemType() == "Node" ) {
-                Node * node = dynamic_cast<Node *>(comp);
-                if ( m_nodeList.contains( node ) ) removeNode( node );
-            } else {
-                if ( m_compList.contains( comp ) ) removeComp( comp );
-            }
-        }
-    }
-    addCompState( NULL, "New State", stateNew );
-    for( Connector* con  : oldConnectors )  {
-        if ( !m_conList.contains( con ) ) addCompRemovedState( con->getUid(), compStrMap.value(con) );
-    }
-    for( Node* node : oldNodes ) {
-        if ( !m_nodeList.contains( node ) ) addCompRemovedState( node->getUid(), compStrMap.value(node) );
-    }
-    for( Component* comp : oldComponents ) {
-        if ( !m_compList.contains( comp ) ) addCompRemovedState( comp->getUid(), compStrMap.value(comp) );
+    for( Connector* conn : conns ) removeConnector( conn );
+
+    for( Component* comp: comps ){
+        if( comp->itemType() == "Node" ) removeNode( (Node*)comp );
+        else                             removeComp( comp );
     }
+    endCicuitChange(); // Calculates created/removed
+
     for( QGraphicsItem* item : selectedItems() ) item->setSelected( false );
-    saveState();
-    endBatchProcess();
+
     m_busy = false;
 }
 
 void Circuit::removeComp( Component* comp )
 {
-    if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
     m_compRemoved = false;
     comp->remove();
     if( !m_compRemoved ) return;
@@ -682,6 +624,7 @@ void Circuit::removeComp( Component* comp )
 void Circuit::removeNode( Node* node )
 {
     if( !m_nodeList.contains(node) ) return;
+    if( m_deleting ) return;
     m_nodeList.remove( node );
     m_compMap.remove( node->getUid() );
     removeItem( node );
@@ -690,16 +633,18 @@ void Circuit::removeNode( Node* node )
 
 void Circuit::removeConnector( Connector* conn )
 {
-    if (!m_conList.contains(conn)) return;
+    if( !m_connList.contains(conn) ) return;
     conn->remove();
-    m_conList.remove( conn );
-    m_removedConnectors.insert( conn );
+    m_connList.remove( conn );
+    m_compMap.remove( conn->getUid() );
+    m_removedComps.insert( conn );
 }
 
 void Circuit::clearCircuit() // Remove everything ( Clear Circuit )
 {
     if( m_conStarted ) return;
     m_deleting = true;
+    if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
 
     QSet<Component*> compList = m_compList;
     for( Component* comp : compList )
@@ -717,20 +662,24 @@ void Circuit::clearCircuit() // Remove everything ( Clear Circuit )
     m_deleting = false;
 }
 
-void Circuit::deselectAll()
-{ for( QGraphicsItem* item : selectedItems() ) item->setSelected( false ); }
-
 void Circuit::saveBackup()
 {
     if( m_simulator->isRunning() ) return;
     if( !m_changed || m_conStarted || m_busy || m_deleting ) return;
     m_changed = false;
-    m_busy = true;
 
+    m_busy = true;
     saveString( m_backupPath, circuitToString() ); // Backup file
     m_busy = false;
 }
 
+void Circuit::setChanged()
+{
+    m_changed = true;
+    QString title = MainWindow::self()->windowTitle();
+    if( !title.endsWith('*') ) MainWindow::self()->setWindowTitle(title+'*');
+}
+
 void Circuit::saveState()
 {
     if( m_conStarted || m_circState.size() == 0 ) return;
@@ -740,7 +689,8 @@ void Circuit::saveState()
     {
         m_redoStack.append( m_circState );
         m_redoIndex++;
-    } else{                     // Redo or new state
+    }
+    else{                     // Redo or new state
         if( !m_redo ){
             if( m_redoStack.size() )
             {
@@ -757,19 +707,12 @@ void Circuit::saveState()
         }
         m_undoIndex++;
     }
-    m_circState.clear();
+    clearCircuitState();
+    m_cicuitChange = 0;  // Ends all CicuitChanges
 
-    clearRemovedComps();
-qDebug() << "Circuit::saveState Undo:"<< m_undoStack.size()<<m_undoIndex
-                              <<"Redo:"<<m_redoStack.size()<<m_redoIndex<<"\n";
-
-}
-
-void Circuit::setChanged()
-{
-    m_changed = true;
-    QString title = MainWindow::self()->windowTitle();
-    if( !title.endsWith('*') ) MainWindow::self()->setWindowTitle(title+'*');
+    // clear Removed Comps;
+    for( CompBase* comp : m_removedComps ) delete comp;
+    m_removedComps.clear();
 }
 
 void Circuit::unSaveState()
@@ -779,187 +722,180 @@ void Circuit::unSaveState()
     m_undoIndex--;
 }
 
-void Circuit::addCompState( CompBase* c, QString p, stateMode state )
+void Circuit::beginCicuitModify() // Don't create/remove
+{
+    //qDebug() << "Circuit::beginCicuitModify";
+    if( !m_cicuitChange ) clearCircuitState();
+    m_cicuitChange++;
+}
+
+void Circuit::endCicuitModify() // Don't create/remove
+{
+    //qDebug() << "Circuit::endCicuitModify";
+    if( m_cicuitChange > 0 ){
+        m_cicuitChange--;
+        if( m_cicuitChange == 0 ) saveState();
+    }
+}
+
+void Circuit::beginCicuitChange() // Save current state
+{
+    //qDebug() << "Circuit::beginCicuitChange";
+    beginCicuitModify();
+
+    m_oldConns = m_connList;
+    m_oldComps = m_compList;
+    m_oldNodes = m_nodeList;
+    m_compStrMap.clear();      /// FIXME: optimize this, we are saving the whole circuit every time
+
+    //save all comps
+    for( Connector* conn : m_oldConns ) m_compStrMap.insert( conn, conn->toString() );
+    for( Node*      node : m_oldNodes ) m_compStrMap.insert( node, node->toString() );
+    for( Component* comp : m_oldComps ) m_compStrMap.insert( comp, comp->toString() );
+}
+
+void Circuit::endCicuitChange()   // Calculates created/removed
+{
+    //qDebug() << "Circuit::endCicuitChange  Removed";
+    // Items Removed
+    for( Connector* conn : m_oldConns-m_connList ) addCompState( conn->getUid(), COMP_STATE_REMOVED, m_compStrMap.value(conn) );
+    for( Node*      node : m_oldNodes-m_nodeList ) addCompState( node->getUid(), COMP_STATE_REMOVED, m_compStrMap.value(node) );
+    for( Component* comp : m_oldComps-m_compList ) addCompState( comp->getUid(), COMP_STATE_REMOVED, m_compStrMap.value(comp) );
+    //qDebug() << "Circuit::endCicuitChange  Created";
+    // Items Created
+    for( Component* comp : m_compList-m_oldComps ) addCompState( comp->getUid(), COMP_STATE_CREATED, "" );
+    for( Node*      node : m_nodeList-m_oldNodes ) addCompState( node->getUid(), COMP_STATE_CREATED, "" );
+    for( Connector* conn : m_connList-m_oldConns ) addCompState( conn->getUid(), COMP_STATE_CREATED, "" );
+    //qDebug() << "Circuit::endCicuitChange  Done";
+    endCicuitModify();
+}
+
+void Circuit::saveCompState( QString name, QString property, QString value )
+{
+    clearCircuitState();
+    addCompState( name, property, value );
+    saveState();
+}
+
+void Circuit::addCompState( QString name, QString property, QString value )
 {
     if( m_loading || m_deleting ) return;
-    QString type = "NULL";
-    if( c ) type = c->itemType();
-    if ( c )
-        qDebug() << "Circuit::addCompState" << c->getUid() << p << state;
-    else
-        qDebug() << "Circuit::addCompState" << type<<p<<state;
-//qDebug() <<(state&stateNew)<<(state&stateAdd)<<(state&stateSave)<<((int)state&(int)stateSave);
-    if( state & stateNew )
-    {
-        m_circState.clear();
-    }
-    if( state & stateAdd )
-    {
-        compState cState;
-        Q_ASSERT( c );
-        cState.component = c->getUid();
-        cState.property  = p;
-        if( p == COMP_STATE_REMOVED ) cState.valStr = c->toString();
-        else             cState.valStr = c->getPropStr( p );
+    //qDebug() << "Circuit::addCompState    " << name << property;// << value;
 
-        if( c->itemType() == "Connector" )
-        {
-            Connector* con = (Connector*)c;
-            if( p == COMP_STATE_CREATED )
-            {
-                cState.valStr = con->startPinId(); // Save Connector start Pin id.
-            }
-        }
-        if ( m_undo ) m_circState.compStates.prepend( cState );
-        else m_circState.compStates.append( cState );
-    }
-    if( state & stateSave )
-    {
-//qDebug() << "Circuit::addCompState saveState";
-        if( !m_batchProcess )
-            saveState();
-    }
-}
+    compState cState{ name, property, value };
 
-void Circuit::undo()
-{
-    if( m_busy || m_deleting || m_conStarted || m_undoIndex < 0 ) return;
-qDebug() << "\nCircuit::undo"<<m_undoIndex<<m_redoIndex;
-    m_undo = true;
-    if( m_undoIndex > m_undoStack.size() )
-    {
-        qDebug() << "Circuit::redo index Error"<< m_undoStack.size()<<m_undoIndex;
-        clearUndoRedo();
-        return;
-    }
-    circState step = m_undoStack.at( m_undoIndex );
-    if( restoreState( step ) )
-    {
-        m_undoIndex--;
-        saveState();
-
-        if( m_board && m_board->m_boardMode )
-            for( Connector* con : m_conList  ) con->setVisib( false );
-        for( Connector* con : m_conList ) {
-            con->startPin()->isMoved();
-            con->endPin()->isMoved();
-        }
-    }
-    else clearUndoRedo();
-    m_undo = false;
-
-//qDebug() << "Circuit::undo Undo:"<<m_undoStack.size()<<m_undoIndex
-//                        <<"Redo:"<<m_redoStack.size()<<m_redoIndex<<"\n";
-//qDebug() << "Circuit::undo-----------------------\n";
-}
-
-void Circuit::redo()
-{
-    if( m_busy || m_deleting || m_conStarted || m_redoIndex < 0 ) return;
-qDebug() << "\nCircuit::redo"<<m_undoIndex<<m_redoIndex;
-    m_redo = true;
-    if( m_redoIndex > m_redoStack.size() )
-    {
-        qDebug() << "Circuit::redo index Error"<< m_redoStack.size()<<m_redoIndex;
-        clearUndoRedo();
-        return;
-    }
-    circState step = m_redoStack.at( m_redoIndex );
-    if( restoreState( step ) )
-    {
-        m_redoIndex--;
-        saveState();
-        if( m_redoIndex < 0 ) m_redoStack.clear();
-
-        if(  m_board && m_board->m_boardMode )
-            for( Connector* con : m_conList  ) con->setVisib( false );
-
-        for( Connector* con : m_conList ) {
-            con->startPin()->isMoved();
-            con->endPin()->isMoved();
-        }
-    }
-    else clearUndoRedo();
-    m_redo = false;
-
-//qDebug() << "Circuit::redo Undo:"<< m_undoStack.size()<<m_undoIndex
-//                        <<"Redo:"<<m_redoStack.size()<<m_redoIndex<<"\n";
-//qDebug() << "Circuit::redo-----------------------\n";
+    if ( m_undo ) m_circState.compStates.prepend( cState );
+    else          m_circState.compStates.append( cState );
 }
 
 bool Circuit::restoreState( circState step )
 {
-    beginBatchProcess();
     if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
     m_busy = true;
 
-    if( m_undo || m_redo ) addCompState( NULL, "", stateNew ); // Start new Undo/Redo state
+    clearCircuitState();
 
     int iStep, i;
-    if( m_undo ) {
-        iStep = -1; i = step.compStates.size() - 1 ;
-    } else {
-        iStep = 1; i = 0;
-    }
+    if( m_undo ) { iStep = -1; i = step.compStates.size()-1; }
+    else         { iStep =  1; i = 0; }
 
-    while( i>=0 && i < step.compStates.size() ) {
+    while( i>=0 && i < step.compStates.size() )
+    {
         compState cState = step.compStates[i];
         i += iStep;
         QString compName = cState.component;
         QString propName = cState.property;
         QString propVal  = cState.valStr;
         CompBase* comp   = m_compMap.value( compName );
-qDebug() << "Circuit::restoreState"<<compName<<cState.property<<comp;
 
-        if( propName == COMP_STATE_REMOVED )
+//qDebug() << "Circuit::restoreState -->"<< compName << propName << comp;
+
+        if( propName == COMP_STATE_REMOVED )       // Create Item
         {
             loadStrDoc( propVal );
-            if( m_newComp ) addCompState( m_newComp, COMP_STATE_CREATED, stateAdd );
-        } else if ( propName == COMP_STATE_CREATED ) {
-            if( comp && comp->itemType() != "Connector" )
-            {
-                addCompState( comp, COMP_STATE_REMOVED, stateAdd );
-                if( comp->itemType() == "Node")
-                {
-                    Node* node = (Node*)comp;
-                    removeNode( node );
-                }
-                else removeComp( (Component*)comp );
-            }else{
-                QString propVal  = cState.valStr;
-                Pin* pin = m_pinMap.value( propVal ); // Find Connector start Pin from id.
-                if( !pin ){
-                    //qDebug() << "Circuit::restoreState Error NULL Pin"<<compName<<propVal;
-                    continue; //return false;
-                }
-                Connector* con = pin->connector();
-                if( !con ){
-                    //qDebug() << "Circuit::restoreState Error NULL Connector"<<compName<<propVal;
-                    continue; // return false;
-                }
-                if ( m_conList.contains( con )) {
-                    addCompState( con, COMP_STATE_REMOVED, stateAdd );
-                    removeConnector( con );
-                }
-            }
-
-        } else // Property
+            if( m_newComp ) addCompState( m_newComp->getUid(), COMP_STATE_CREATED, "" );
+        }
+        else if( propName == COMP_STATE_CREATED )  // Remove Item
         {
-            if( !comp ){
-                qDebug() << "Circuit::restoreState Error restoring"<<compName<<propName<<propVal;
-                continue;
-            }
-            addCompState( comp, propName, stateAdd );
+            if( !comp ) continue;
+            addCompState( comp->getUid(), COMP_STATE_REMOVED, comp->toString() );
+
+            if     ( comp->itemType() == "Connector" ) removeConnector( (Connector*)comp );
+            else if( comp->itemType() == "Node"      ) removeNode( (Node*)comp );
+            else                                       removeComp( (Component*)comp );
+        }
+        else {                            // Property
+            if( !comp ) continue;
+            addCompState( compName, propName, comp->getPropStr( propName ) );
             comp->setPropStr( propName, propVal );
         }
     }
+    saveState();
+
     m_LdPinMap.clear();
     m_busy = false;
     update();
-    endBatchProcess();
     return true;
 }
 
+void Circuit::undo()
+{
+    if( m_busy || m_deleting || m_conStarted || m_undoIndex < 0 ) return;
+
+//qDebug() << "\nCircuit::undo"<<m_undoIndex<<m_redoIndex;
+
+    if( m_undoIndex > m_undoStack.size() )
+    {
+        qDebug() << "Circuit::redo index Error"<< m_undoStack.size()<<m_undoIndex;
+        clearUndoRedo();
+        return;
+    }
+    m_undo = true;
+    circState step = m_undoStack.at( m_undoIndex );
+    if( restoreState( step ) )
+    {
+        m_undoIndex--;
+        finishUndoRedo();
+    }
+    else clearUndoRedo();
+    m_undo = false;
+}
+
+void Circuit::redo()
+{
+    if( m_busy || m_deleting || m_conStarted || m_redoIndex < 0 ) return;
+
+//qDebug() << "\nCircuit::redo"<<m_undoIndex<<m_redoIndex;
+
+    if( m_redoIndex > m_redoStack.size() )
+    {
+        qDebug() << "Circuit::redo index Error"<< m_redoStack.size()<<m_redoIndex;
+        clearUndoRedo();
+        return;
+    }
+    m_redo = true;
+    circState step = m_redoStack.at( m_redoIndex );
+    if( restoreState( step ) )
+    {
+        m_redoIndex--;
+        finishUndoRedo();
+        if( m_redoIndex < 0 ) m_redoStack.clear(); /// ???
+    }
+    else clearUndoRedo();
+    m_redo = false;
+}
+
+void Circuit::finishUndoRedo()
+{
+    for( Connector* con : m_connList ) {
+        if( m_board && m_board->m_boardMode ) con->setVisib( false );
+        else{
+            con->startPin()->isMoved();
+            con->endPin()->isMoved();
+        }
+    }
+}
+
 void Circuit::clearUndoRedo()
 {
     qDebug() << "Circuit::clearUndoRedo Warning: Stack Cleared"<<m_redoIndex<<m_undoIndex<<"\n";
@@ -974,7 +910,7 @@ void Circuit::copy( QPointF eventpoint )
 {
     if( m_conStarted ) return;
 
-    m_eventpoint = toGrid(eventpoint);
+    m_eventpoint = toGrid( eventpoint );
 
     QList<CompBase*> complist;
     QList<CompBase*> conlist;
@@ -1006,7 +942,7 @@ void Circuit::paste( QPointF eventpoint )
     if( m_simulator->isRunning() ) CircuitWidget::self()->powerCircOff();
 
     bool animate = m_animate;
-    m_busy = true;
+    m_busy    = true;
     m_pasting = true;
     for( QGraphicsItem*item : selectedItems() ) item->setSelected( false );
 
@@ -1016,37 +952,38 @@ void Circuit::paste( QPointF eventpoint )
     circuit += QApplication::clipboard()->text();
     circuit += "\n</circuit>";
 
+    beginCicuitChange();
     loadStrDoc( circuit );
+    /// clearCircuitState(); // ??? clear all state generated by copy component properties
+    endCicuitChange();
 
     setAnimate( animate );
     m_pasting = false;
     m_busy = false;
 }
 
-void Circuit::newconnector( Pin* startpin )
+void Circuit::newconnector( Pin* startpin, bool save )
 {
-    beginBatchProcess();
-    addCompState( NULL, "", stateNew );
+    if( save ) beginCicuitChange();
+
     m_conStarted = true;
 
     QString type = QString("Connector");
     QString id = type+"-"+newConnectorId() ;
 
     m_newConnector = new Connector( type, id, startpin );
-    m_conList.insert( m_newConnector );
+    m_connList.insert( m_newConnector );
 
     QPoint p1 = startpin->scenePos().toPoint();
     QPoint p2 = startpin->scenePos().toPoint();
     m_newConnector->addConLine( p1.x(), p1.y(), p2.x(), p2.y(), 0 );
 }
 
-void Circuit::closeconnector( Pin* endpin )
+void Circuit::closeconnector( Pin* endpin, bool save )
 {
     m_conStarted = false;
     m_newConnector->closeCon( endpin );
-    addCompState( m_newConnector, COMP_STATE_CREATED, stateAdd );
-    saveState();
-    endBatchProcess();
+    if( save ) endCicuitChange();
 }
 
 void Circuit::deleteNewConnector()
@@ -1058,7 +995,7 @@ void Circuit::deleteNewConnector()
 }
 
 void Circuit::updateConnectors()
-{ for( Connector* con : m_conList ) con->updateLines(); }
+{ for( Connector* con : m_connList ) con->updateLines(); }
 
 void Circuit::addNode( Node* node )
 {
@@ -1109,7 +1046,7 @@ void Circuit::mousePressEvent( QGraphicsSceneMouseEvent* event )
     else if( event->button() == Qt::RightButton )
     {
         if( m_conStarted ) event->accept();
-        else                QGraphicsScene::mousePressEvent( event );
+        else               QGraphicsScene::mousePressEvent( event );
     }
     else if( event->button() == Qt::MidButton )
         QGraphicsScene::mousePressEvent( event );
@@ -1132,7 +1069,7 @@ void Circuit::mouseMoveEvent( QGraphicsSceneMouseEvent* event )
     if( m_conStarted )
     {
         event->accept();
-        if(event->modifiers() & Qt::ShiftModifier) m_newConnector->m_freeLine = true;
+        if( event->modifiers() & Qt::ShiftModifier) m_newConnector->m_freeLine = true;
         m_newConnector->updateConRoute( 0l, event->scenePos() );
     }
     QGraphicsScene::mouseMoveEvent( event );
@@ -1171,11 +1108,11 @@ void Circuit::keyPressEvent( QKeyEvent* event )
             Component* enterItem = createItem( compNam, compNam+"-"+newSceneId() );
             if( enterItem )
             {
-                saveState();
                 QPoint cPos = QCursor::pos()-CircuitView::self()->mapToGlobal( QPoint(0,0));
                 enterItem->setPos( toGrid( CircuitView::self()->mapToScene( cPos ) ) );
                 addItem( enterItem );
                 m_compList.insert( enterItem );
+                saveCompState( enterItem->getUid(), COMP_STATE_CREATED, "" );
             }
         }
     }
@@ -1216,7 +1153,7 @@ void Circuit::keyPressEvent( QKeyEvent* event )
         {
             for( Component* com : m_compList ) com->setSelected( true );
             for( Node*      nod : m_nodeList ) nod->setSelected( true );
-            for( Connector* con : m_conList  ) con->setSelected( true );
+            for( Connector* con : m_connList  ) con->setSelected( true );
         }
         else if( key == Qt::Key_R )
         {
@@ -1275,12 +1212,12 @@ void Circuit::dropEvent( QGraphicsSceneDragDropEvent* event )
             Component* enterItem = createItem( "Image", newSceneId() );
             if( enterItem )
             {
-                saveState();
                 QPoint cPos = QCursor::pos()-CircuitView::self()->mapToGlobal( QPoint(0,0));
                 enterItem->setPos( CircuitView::self()->mapToScene( cPos ) );
                 enterItem->setBackground( file );
                 addItem( enterItem );
                 m_compList.insert( enterItem );
+                saveCompState( enterItem->getUid(), COMP_STATE_CREATED, "" );
         }   }
         else CircuitWidget::self()->loadCirc( id );
 }   }
