@@ -14,7 +14,7 @@ class QGraphicsProxyWidget;
 class MAINMODULE_EXPORT SwitchBase : public MechContact
 {
     public:
-        SwitchBase( QObject* parent, QString type, QString id );
+        SwitchBase( QString type, QString id );
         ~SwitchBase();
 
         virtual void updateStep() override;
@@ -39,6 +39,8 @@ class MAINMODULE_EXPORT SwitchBase : public MechContact
         
         CustomButton* m_button;
         QGraphicsProxyWidget* m_proxy;
+
+        QMetaObject::Connection m_keyEventConn;
 };
 
 #endif
