@@ -87,7 +87,7 @@ Pin::~Pin()
 void Pin::remove()
 {
     setConnector( NULL );
-    m_component->inStateChanged( 1 );          // Used by node to remove
+    if( !Circuit::self()->undoRedo() ) m_component->pinMessage( 1 ); // Used by node to remove
     m_component->remSignalPin( this );
 }
 
@@ -168,8 +168,8 @@ Pin* Pin::connectPin( bool connect )      // Auto-Connect
               && pin->isVisible() && !pin->isObscuredBy( m_component ) ) _pin = pin;
             if( connect )
             {
-                Circuit::self()->newconnector( this );
-                Circuit::self()->closeconnector( pin );
+                Circuit::self()->newconnector( this, true );
+                Circuit::self()->closeconnector( pin, true );
             }
             break;
         }
@@ -219,8 +219,8 @@ void Pin::mousePressEvent( QGraphicsSceneMouseEvent* event )
                 { event->ignore(); return; }
             }
             event->accept();
-            if( Circuit::self()->is_constarted() ) Circuit::self()->closeconnector( this );
-            else                                   Circuit::self()->newconnector( this );
+            if( Circuit::self()->is_constarted() ) Circuit::self()->closeconnector( this, true );
+            else                                   Circuit::self()->newconnector( this, true );
 }   }   }
 
 void Pin::setLabelText( QString label, bool over )
@@ -339,7 +339,7 @@ void Pin::setIsBus( bool bus )
     if( my_connector ) my_connector->setIsBus( true );
     if( m_conPin ) m_conPin->setIsBus( true );
     
-    m_component->inStateChanged( 2 );         // Propagate Is Bus (Node)
+    m_component->pinMessage( 2 );         // Propagate Is Bus (Node)
 
     update();
 }
