@@ -40,7 +40,7 @@ Component* SubPackage::construct( QString type, QString id )
 LibraryItem* SubPackage::libraryItem()
 {
     return new LibraryItem(
-        simulideTr("Package", "Package" ),
+        tr("Package"),
         "Other",
         "resistordip.png",
         "Package",
@@ -338,7 +338,9 @@ void SubPackage::editPin()
 }
 
 void SubPackage::editFinished( int )
-{ if( m_changed ) Circuit::self()->saveState(); }
+{
+    /// FIXME UNDOREDO: if( m_changed ) Circuit::self()->saveState();
+}
 
 void SubPackage::deleteEventPin()
 {
@@ -473,8 +475,6 @@ void SubPackage::slotSave()
 
 void SubPackage::loadPackage()
 {
-    Circuit::self()->addCompState( this, "Package_File" );
-
     QDir pkgDir;
     QString dir;
 
@@ -490,6 +490,8 @@ void SubPackage::loadPackage()
                        tr("Packages (*.package);;All files (*.*)"));
 
     if( fileName.isEmpty() ) return; // User cancels loading
+
+    Circuit::self()->saveCompState( m_id, "Package_File", fileName );
     setPackage( fileName );
 
     QDir pdir = QFileInfo( Circuit::self()->getFilePath() ).absoluteDir();
@@ -591,6 +593,7 @@ void SubPackage::paint( QPainter* p, const QStyleOptionGraphicsItem* option, QWi
 //_____________________________________________________________
 //_____________________________________________________________
 
+#define tr(str) simulideTr("EditDialog",str)
 
 EditDialog::EditDialog( SubPackage* pack, Pin* eventPin, QWidget* parent )
           : QDialog( parent, Qt::WindowCloseButtonHint )
